pub struct Options {Show 14 fields
pub cols: u16,
pub rows: u16,
pub cell_width: u16,
pub cell_height: u16,
pub settle: Duration,
pub deadline: Duration,
pub input: Vec<u8>,
pub initial_delay: Duration,
pub wait_for: Option<String>,
pub max_bytes: usize,
pub opentui_host: bool,
pub color: ColorMode,
pub env: BTreeMap<String, String>,
pub inherit_env: bool,
}Expand description
Configuration for observing one terminal shot or starting a live session.
Fields
cols: u16rows: u16cell_width: u16cell_height: u16settle: Durationdeadline: Durationinput: Vec<u8>initial_delay: Durationwait_for: Option<String>max_bytes: usizeopentui_host: boolcolor: ColorModeenv: BTreeMap<String, String>Additional environment values set in the observed terminal application.
inherit_env: boolWhether the terminal application inherits the parent process environment.